@@ -1288,26 +1288,20 @@ gsd_mouse_manager_stop (GsdMouseManager *manager)
 
         g_debug ("Stopping mouse manager");
 
+        if (manager->priv->start_idle_id != 0) {
+                g_source_remove (manager->priv->start_idle_id);
+                manager->priv->start_idle_id = 0;
+        }
+
         if (p->device_manager != NULL) {
                 g_signal_handler_disconnect (p->device_manager, p->device_added_id);
                 g_signal_handler_disconnect (p->device_manager, p->device_removed_id);
                 p->device_manager = NULL;
         }
 
-        if (p->mouse_a11y_settings != NULL) {
-                g_object_unref (p->mouse_a11y_settings);
-                p->mouse_a11y_settings = NULL;
-        }
-
-        if (p->mouse_settings != NULL) {
-                g_object_unref (p->mouse_settings);
-                p->mouse_settings = NULL;
-        }
-
-        if (p->touchpad_settings != NULL) {
-                g_object_unref (p->touchpad_settings);
-                p->touchpad_settings = NULL;
-        }
+        g_clear_object (&p->mouse_a11y_settings);
+        g_clear_object (&p->mouse_settings);
+        g_clear_object (&p->touchpad_settings);
 
         set_locate_pointer (manager, FALSE);
 }
@@ -1324,26 +1318,11 @@ gsd_mouse_manager_finalize (GObject *object)
 
         g_return_if_fail (mouse_manager->priv != NULL);
 
+        gsd_mouse_manager_stop (mouse_manager);
+
         if (mouse_manager->priv->blacklist != NULL)
                 g_hash_table_destroy (mouse_manager->priv->blacklist);
 
-        if (mouse_manager->priv->start_idle_id != 0)
-                g_source_remove (mouse_manager->priv->start_idle_id);
-
-        if (mouse_manager->priv->device_manager != NULL) {
-                g_signal_handler_disconnect (mouse_manager->priv->device_manager, mouse_manager->priv->device_added_id);
-                g_signal_handler_disconnect (mouse_manager->priv->device_manager, mouse_manager->priv->device_removed_id);
-        }
-
-        if (mouse_manager->priv->mouse_settings != NULL)
-                g_object_unref (mouse_manager->priv->mouse_settings);
-
-        if (mouse_manager->priv->mouse_a11y_settings != NULL)
-                g_object_unref (mouse_manager->priv->mouse_a11y_settings);
-
-        if (mouse_manager->priv->touchpad_settings != NULL)
-                g_object_unref (mouse_manager->priv->touchpad_settings);
-
         G_OBJECT_CLASS (gsd_mouse_manager_parent_class)->finalize (object);
 }
 
